@@ -10,8 +10,9 @@ from re import findall
 from pathlib import Path
 from urllib import request
 from mutagen.mp3 import MP3
+from time import sleep
 
-__version__:str='1.4.0'
+__version__:str='1.4.4'
 __author__:str='Shayan Heidari'
 __copyright__:str='CopyRight 2022'
 
@@ -58,7 +59,8 @@ class Bot:
 	def __init__(self, auth,displayWelcome=True,):
 		if len(auth) != 32: print('Your account AUTH ID is incorrect, please check and then try again.'); exit()
 		if displayWelcome:
-			print(f'This library was created by {__author__}, with versions {__version__} and {__copyright__}.\nLibrary activated ...\n')
+			text:str=f'This library was created by {__author__}, with versions {__version__} and {__copyright__}.\nLibrary activated ...\n'
+			for char in text: print(char, flush=True, end=''); sleep(.1)
 		self.auth = auth
 		self.enc = Encryption(self.auth)
 
@@ -215,7 +217,7 @@ class Bot:
 					t = True
 				except:
 					t = False
-			
+
 			return j
 		else:
 			t = round(len(file_byte) / 131072 + 1)
@@ -241,7 +243,7 @@ class Bot:
 					j = k + 131072
 					j = round(j / 1024)
 					j2 = round(len(file_byte) / 1024)
-					print(str(j) + 'kb / ' + str(j2) + ' kb')                
+					print(str(j) + 'kb / ' + str(j2) + ' kb')
 				else:
 					k = i - 1
 					k = k * 131072
@@ -261,7 +263,7 @@ class Bot:
 						except:
 							t2 = False
 					j2 = round(len(file_byte) / 1024)
-					print(str(j2) + 'kb / ' + str(j2) + ' kb') 
+					print(str(j2) + 'kb / ' + str(j2) + ' kb')
 					return p
 
 	@staticmethod
@@ -579,7 +581,7 @@ class Bot:
 						"middle_message_id":middle_message_id,
 						},
 					"client": Clients.web
-				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc')))
+				}))}).encode(), headers={'Content-Type': 'application/json'})).read()).get('data_enc'))).get('data').get('messages')
 
 	def sendImage(self, chat_id, file_id , mime , dc_id, access_hash_rec, file_name,  size, thumb_inline , width , height, text=None, message_id=None,):
 		return loads(self.enc.decrypt(loads(request.urlopen(request.Request('https://messengerg2c64.iranlms.ir/', data=dumps({"api_version":"5","auth": self.auth,"data_enc":self.enc.encrypt(dumps({
@@ -870,99 +872,47 @@ class Bot:
 
 class Uploader:
 	def __init__(self, auth,):
-		self.auth=Bot(auth)
+		self.auth=Bot(auth, displayWelcome=False,)
 
-	def sendPhoto(self,object_guid, file, caption=None, message_id=None,):
-		if caption!=None and message_id!=None:
-			byte=open(file, 'rb').read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption, message_id=message_id)
-		elif caption==None and message_id==None:
-			byte=open(file, 'rb').read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,)
-		elif message_id!=None:
-			byte=open(file, 'rb').read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,message_id=message_id,)
-		elif caption!=None:
-			byte=open(file, 'rb').read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption,)
-
-	def sendPhotoWithLink(self, object_guid, link, caption=None, message_id=None):
-		file_name='TyperGames'+str(randint(10000, 999999999))+'.png'
-		if caption!=None and message_id!=None:
-			byte=request.urlopen(request.Request(link)).read()
+	def sendPhoto(self,object_guid, url_or_file, caption=None, message_id=None,):
+		if url_or_file.startswith('http'):
+			file_name='TyperGames'+str(randint(10000, 999999999))+'.png'
+			byte=request.urlopen(request.Request(url_or_file)).read()
 			[width,height]=self.auth.getImageSize(byte)
 			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
 			if rsf!='many_request':
 				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
 				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption, message_id=message_id)
-		elif (caption==None and message_id==None):
-			byte=request.urlopen(request.Request(link)).read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,)
-		elif caption!=None:
-			byte=request.urlopen(request.Request(link)).read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption,)
-		elif message_id!=None:
-			byte=request.urlopen(request.Request(link)).read()
-			[width,height]=self.auth.getImageSize(byte)
-			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height, message_id=message_id,)
-
-	def sendDocument(self, object_guid, file, file_name=None,caption=None, message_id=None):
-		suffix = Path(file).suffix
-		if file_name==None:
-			file_name='TyperGames'+str(randint(10000, 999999999))+suffix
 		else:
-			file_name=file_name+suffix
-		if caption!=None and message_id!=None:
-			byte=open(file, 'rb').read()
+			byte=open(url_or_file, 'rb').read()
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height, caption, message_id)
+
+	def sendDocument(self, object_guid, url_or_file,suffix=None, file_name=None,caption=None, message_id=None):
+		if url_or_file.startswith('http'):
+			if file_name==None:
+				file_name='TyperGames'+str(randint(10000, 999999999))+'.'+suffix
+			else:
+				file_name=file_name+'.'+suffix
+			byte=request.urlopen(request.Request(url_or_file)).read()
+			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendFile(object_guid,rsf['id'] , suffix, rsf['dc_id'] , access, file_name, len(byte), text=caption,message_id=message_id,)
+		else:
+			suffix = Path(url_or_file).suffix
+			if file_name==None:
+				file_name='TyperGames'+str(randint(10000, 999999999))+suffix
+			else:
+				file_name=file_name+suffix
+			byte=open(url_or_file, 'rb').read()
 			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
 			if rsf!='many_request':
 				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
 				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte), text=caption,message_id=message_id,)
-		elif caption==None and message_id==None:
-			byte=open(file, 'rb').read()
-			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte),)
-		elif message_id!=None:
-			byte=open(file, 'rb').read()
-			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte), message_id=message_id)
-		elif caption!=None:
-			byte=open(file, 'rb').read()
-			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
-			if rsf!='many_request':
-				access = self.auth.uploadFile(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
-				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte), text=caption)
 
 	def sendMusic(self,chat_id, url_or_file, file_name=None,caption=None, message_id=None,):
 		if url_or_file.startswith('http'):
